summaryrefslogtreecommitdiff
path: root/viengoos/viengoos.h
diff options
context:
space:
mode:
authorneal <neal>2008-06-23 18:53:02 +0000
committerneal <neal>2008-06-23 18:53:02 +0000
commit914b94ee60a44bb0ffc7a92a2e3011bf72034d01 (patch)
treeb798bfa73ee937fc388dc9c0a7572a8cc95c20e3 /viengoos/viengoos.h
parentfa7c6a09c3f6e063b74f01ce419f12ac1f5ef2f6 (diff)
2008-06-23 Neal H. Walfield <neal@gnu.org>
* viengoos.h (viengoos_tid): New declaration. (ager_tid): New declaration. * viengoos.c (viengoos_tid): New variable. (ager_tid): Likewise. (ager_start): Don't push Viengoos's tid on the stack. Save the ager's tid in AGER_TID and Viengoos's in VIENGOOS_TID. * ager.h (ager_loop): Don't take any arguments. * ager.c: Include "viengoos.h". (ager_loop): Don't take any arguments. Use VIENGOOS_TID, not MAIN_THREAD.
Diffstat (limited to 'viengoos/viengoos.h')
-rw-r--r--viengoos/viengoos.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/viengoos/viengoos.h b/viengoos/viengoos.h
index 5e5434c..cbae9fa 100644
--- a/viengoos/viengoos.h
+++ b/viengoos/viengoos.h
@@ -1,5 +1,5 @@
-/* priv.h - Private declarations.
- Copyright (C) 2007 Free Software Foundation, Inc.
+/* viengoos.h - Viengoos declarations.
+ Copyright (C) 2007, 2008 Free Software Foundation, Inc.
Written by Neal H. Walfield <neal@gnu.org>.
This file is part of the GNU Hurd.
@@ -37,4 +37,9 @@ extern int main (int, char *[]);
required for booting. */
extern void find_components (void);
+/* Viengoos's tid. */
+l4_thread_id_t viengoos_tid;
+/* Ager's tid. */
+l4_thread_id_t ager_tid;
+
#endif